@@ -100,7 +100,7 @@ class Migration(SchemaMigration):
             'Meta': {'ordering': "('submit_date',)", 'object_name': 'ThreadedComment', '_ormbases': ['comments.Comment']},
             'by_author': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'comment_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['comments.Comment']", 'unique': 'True', 'primary_key': 'True'}),
-            'rating': ('mezzanine.generic.fields.RatingField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.Rating']", 'frozen_by_south': 'True'}),
+            #'rating': ('mezzanine.generic.fields.RatingField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.Rating']", 'frozen_by_south': 'True'}),
             'rating_average': ('django.db.models.fields.FloatField', [], {'default': '0'}),
             'rating_count': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
             'rating_sum': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
@@ -114,4 +114,4 @@ class Migration(SchemaMigration):
         }
     }
 
-    complete_apps = ['generic']
\ No newline at end of file
+    complete_apps = ['generic']
